sktools package
===============

Submodules
----------

sktools.encoders module
-----------------------

.. automodule:: sktools.encoders
    :members:
    :undoc-members:
    :show-inheritance:

sktools.imputer module
----------------------

.. automodule:: sktools.imputer
    :members:
    :undoc-members:
    :show-inheritance:

sktools.matrix\_denser module
-----------------------------

.. automodule:: sktools.matrix_denser
    :members:
    :undoc-members:
    :show-inheritance:

sktools.quantilegroups module
-----------------------------

.. automodule:: sktools.quantilegroups
    :members:
    :undoc-members:
    :show-inheritance:

sktools.selectors module
------------------------

.. automodule:: sktools.selectors
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: sktools
    :members:
    :undoc-members:
    :show-inheritance:
